AsyncOptionsSource class final

Inheritance

Constructors

AsyncOptionsSource(Future<List<FieldOption>> loader())

Properties

hashCode int
The hash code for this object.
no setterinherited
loader Future<List<FieldOption>> Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<List<FieldOption>>
Resolves the options, awaiting if necessary.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited