CustomValidator class

Inline custom validator — quick one-liners without subclassing.

Inheritance

Constructors

CustomValidator(FutureOr<String?> fn(dynamic value, Map<String, dynamic> formValues))
const

Properties

fn FutureOr<String?> Function(dynamic value, Map<String, dynamic> formValues)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(dynamic value, Map<String, dynamic> formValues) FutureOr<String?>
Validates value in the context of formValues (all current field values).
override

Operators

operator ==(Object other) bool
The equality operator.
inherited