MinValueValidator class

Ensures a numeric value is at least min.

Inheritance

Constructors

MinValueValidator(num min, {String? message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
final
min num
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(dynamic value, Map<String, dynamic> _) String?
Validates value in the context of formValues (all current field values).
override

Operators

operator ==(Object other) bool
The equality operator.
inherited