MinLengthValidator class
Ensures a string value has at least min characters.
- Inheritance
-
- Object
- FieldValidator
- MinLengthValidator
Constructors
- MinLengthValidator(int min, {String? message})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
dynamic value, Map< String, dynamic> _) → String? -
Validates
valuein the context offormValues(all current field values).override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited